==> greendeck-proxygrabber-0.1.0.tar.gz: greendeck-proxygrabber-0.1.0/greendeck_proxygrabber/src/proxygrabber/constant.py <==
COMBINED_COUNTRY_URL_HTTPS = [
    'https://www.proxy-list.download/api/v1/get?type=https&anon=elite',
    'https://free-proxy-list.net/uk-proxy.html',
    'https://www.duplichecker.com/free-proxy-list.php',
    'https://raw.githubusercontent.com/clarketm/proxy-list/master/proxy-list-raw.txt'
]

COMBINED_COUNTRY_URL_HTTP = [
    'https://www.proxy-list.download/api/v1/get?type=http&anon=elite',
    'https://free-proxy-list.net/uk-proxy.html',
    'https://www.duplichecker.com/free-proxy-list.php',
    'https://raw.githubusercontent.com/clarketm/proxy-list/master/proxy-list-raw.txt'
]

COMBINED_DE_URL_HTTPS = [
    'https://www.proxy-list.download/api/v0/get?l=en&t=https',
]

COMBINED_DE_URL_HTTP = [
    'https://www.proxy-list.download/api/v0/get?l=en&t=http',
]

COMBINED_UK_URL_HTTPS = [
    'https://www.proxy-list.download/api/v0/get?l=en&t=https',
    'https://free-proxy-list.net/uk-proxy.html',
]

COMBINED_UK_URL_HTTP = [
    'https://www.proxy-list.download/api/v0/get?l=en&t=http',
    'https://free-proxy-list.net/uk-proxy.html'
]

COMBINED_US_URL_HTTPS = [
    'https://www.proxy-list.download/api/v0/get?l=en&t=https',
    'https://www.us-proxy.org/',
    'http://www.xroxy.com/proxy-country-US'
]

COMBINED_US_URL_HTTP = [
    'https://www.proxy-list.download/api/v0/get?l=en&t=http',
    'https://www.us-proxy.org/',
    'http://www.xroxy.com/proxy-country-US'
]

GENERALISED_HTTPS = [
    'http://free-proxy.cz/en/proxylist/country/country_code/all/ping/all/1'
]

GENERALISED_HTTP = [
    'http://free-proxy.cz/en/proxylist/country/country_code/http/ping/all/1'
]

==> greendeck-proxygrabber-0.1.3.tar.gz: greendeck-proxygrabber-0.1.3/greendeck_proxygrabber/src/proxygrabber/constant.py <==
COMBINED_COUNTRY_URL_HTTPS = [
    'https://www.proxy-list.download/api/v1/get?type=https&anon=elite',
    'https://free-proxy-list.net/uk-proxy.html',
    'https://www.duplichecker.com/free-proxy-list.php',
    'https://raw.githubusercontent.com/clarketm/proxy-list/master/proxy-list-raw.txt',
    'https://raw.githubusercontent.com/fate0/proxylist/master/proxy.list'
]

COMBINED_COUNTRY_URL_HTTP = [
    'https://www.proxy-list.download/api/v1/get?type=http&anon=elite',
    'https://free-proxy-list.net/uk-proxy.html',
    'https://www.duplichecker.com/free-proxy-list.php',
    'https://raw.githubusercontent.com/clarketm/proxy-list/master/proxy-list-raw.txt',
    'https://raw.githubusercontent.com/fate0/proxylist/master/proxy.list'
]

COMBINED_DE_URL_HTTPS = [
    'https://www.proxy-list.download/api/v0/get?l=en&t=https',
]

COMBINED_DE_URL_HTTP = [
    'https://www.proxy-list.download/api/v0/get?l=en&t=http',
]

COMBINED_UK_URL_HTTPS = [
    'https://www.proxy-list.download/api/v0/get?l=en&t=https',
    'https://free-proxy-list.net/uk-proxy.html',
]

COMBINED_UK_URL_HTTP = [
    'https://www.proxy-list.download/api/v0/get?l=en&t=http',
    'https://free-proxy-list.net/uk-proxy.html'
]

COMBINED_US_URL_HTTPS = [
    'https://www.proxy-list.download/api/v0/get?l=en&t=https',
    'https://www.us-proxy.org/',
    'http://www.xroxy.com/proxy-country-US'
]

COMBINED_US_URL_HTTP = [
    'https://www.proxy-list.download/api/v0/get?l=en&t=http',
    'https://www.us-proxy.org/',
    'http://www.xroxy.com/proxy-country-US'
]

GENERALISED_HTTPS = [
    'http://free-proxy.cz/en/proxylist/country/country_code/all/ping/all/1'
]

GENERALISED_HTTP = [
    'http://free-proxy.cz/en/proxylist/country/country_code/http/ping/all/1'
]
